==> mono-2.10.2.tar.bz2: mono-2.10.2/mcs/class/corlib/Test/System.Security/SecurityStateTest.cs <==
//
// SecurityStateTest.cs - NUnit Test Cases for SecurityState
//
// Author:
//	Sebastien Pouliot (sebastien@ximian.com)
//
// Copyright (C) 2009 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System;
using System.Security;

using NUnit.Framework;

namespace MonoTest.System.Security {

	[TestFixture]
	public class SecurityStateTest {

		class ContreteSecurityState : SecurityState {
			public override void EnsureState ()
			{
				throw new NotImplementedException ();
			}
		}

		[Test]
		public void Defaults ()
		{
			ContreteSecurityState ss = new ContreteSecurityState ();
			Assert.IsFalse (ss.IsStateAvailable (), "IsStateAvailable");
		}
	}
}

#endif

==> mono-4.2.2.10.tar.bz2: mono-4.2.2/mcs/class/corlib/Test/System.Security/SecurityStateTest.cs <==
//
// SecurityStateTest.cs - NUnit Test Cases for SecurityState
//
// Author:
//	Sebastien Pouliot (sebastien@ximian.com)
//
// Copyright (C) 2009 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//


using System;
using System.Security;

using NUnit.Framework;

namespace MonoTests.System.Security {

	[TestFixture]
	public class SecurityStateTest {

		class ContreteSecurityState : SecurityState {
			public override void EnsureState ()
			{
				throw new NotImplementedException ();
			}
		}

		[Test]
		public void Defaults ()
		{
			ContreteSecurityState ss = new ContreteSecurityState ();
			Assert.IsFalse (ss.IsStateAvailable (), "IsStateAvailable");
		}
	}
}
